# coding: utf-8

from supervisely.api.pointcloud.pointcloud_object_api import PointcloudObjectApi
from supervisely.api.pointcloud.pointcloud_episode_tag_api import PointcloudEpisodeObjectTagApi


class PointcloudEpisodeObjectApi(PointcloudObjectApi):
    """
    :class:`PointcloudEpisodeObject<supervisely.pointcloud_annotation.pointcloud_object.PointcloudEpisodeObject>` for :class:`PointcloudEpisodeAnnotation<supervisely.pointcloud_annotation.pointcloud_episode_annotation.PointcloudEpisodeAnnotation>`.
    """

    def __init__(self, api):
        """
        :param api: Api class object
        """
        super().__init__(api)
        self.tag = PointcloudEpisodeObjectTagApi(api)



# coding: utf-8

from supervisely.collection.str_enum import StrEnum


class ProjectType(StrEnum):
    IMAGES = "images"
    VIDEOS = "videos"
    VOLUMES = "volumes"
    POINT_CLOUDS = "point_clouds"
    POINT_CLOUD_EPISODES = "point_cloud_episodes"



from supervisely.nn.inference.object_detection.object_detection import (
    ObjectDetection,
)


class PromptBasedObjectDetection(ObjectDetection):
    def get_info(self) -> dict:
        info = super().get_info()
        info["task type"] = "prompt-based object detection"
        return info



import traceback

import supervisely as sly
from rich.console import Console


def remove_file_run(team_id: int, path: str) -> bool:

    api = sly.Api.from_env()
    console = Console()

    if api.team.get_info_by_id(team_id) is None:
        console.print(f"\nError: Team with ID={team_id} not exists\n", style="bold red")
        return False

    try:
        api.file.remove_file(team_id, path)
        console.print(f"\nFile '{path}' was successfully removed\n", style="bold green")
        return True

    except:
        console.print(f"\nRemoving file failed\n", style="bold red")
        traceback.print_exc()
        return False


def remove_directory_run(team_id: int, path: str) -> bool:

    api = sly.Api.from_env()
    console = Console()

    if api.team.get_info_by_id(team_id) is None:
        console.print(f"\nError: Team with ID={team_id} not exists\n", style="bold red")
        return False

    try:
        api.file.remove_dir(team_id, path)
        console.print(f"\nDirectory '{path}' was successfully removed\n", style="bold green")
        return True

    except:
        console.print(f"\nRemoving directory failed\n", style="bold red")
        traceback.print_exc()
        return False
